aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBenedikt Ritter <britter@apache.org>2017-09-12 16:50:10 +0000
committerBenedikt Ritter <britter@apache.org>2017-09-12 16:50:10 +0000
commitcb9d0a8369704bfc94a84371561d30a6b4317767 (patch)
treee14325a8863893ca8cfb60d0bb7eca70be195c05
parent8e09c4dd0f87cd8e54df851a7e0d4689731b31ea (diff)
downloadapache-commons-bcel-cb9d0a8369704bfc94a84371561d30a6b4317767.tar.gz
Parameter names should be in camel case
git-svn-id: https://svn.apache.org/repos/asf/commons/proper/bcel/trunk@1808133 13f79535-47bb-0310-9956-ffa450edef68
-rw-r--r--src/main/java/org/apache/bcel/classfile/StackMapEntry.java62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/main/java/org/apache/bcel/classfile/StackMapEntry.java b/src/main/java/org/apache/bcel/classfile/StackMapEntry.java
index 4f15fff2..291b0772 100644
--- a/src/main/java/org/apache/bcel/classfile/StackMapEntry.java
+++ b/src/main/java/org/apache/bcel/classfile/StackMapEntry.java
@@ -47,8 +47,8 @@ public final class StackMapEntry implements Node, Cloneable
* @param input Input stream
* @throws IOException
*/
- StackMapEntry(final DataInput input, final ConstantPool constant_pool) throws IOException {
- this(input.readByte() & 0xFF, -1, null, null, constant_pool);
+ StackMapEntry(final DataInput input, final ConstantPool constantPool) throws IOException {
+ this(input.readByte() & 0xFF, -1, null, null, constantPool);
if (frame_type >= Const.SAME_FRAME && frame_type <= Const.SAME_FRAME_MAX) {
byte_code_offset = frame_type - Const.SAME_FRAME;
@@ -56,11 +56,11 @@ public final class StackMapEntry implements Node, Cloneable
frame_type <= Const.SAME_LOCALS_1_STACK_ITEM_FRAME_MAX) {
byte_code_offset = frame_type - Const.SAME_LOCALS_1_STACK_ITEM_FRAME;
types_of_stack_items = new StackMapType[1];
- types_of_stack_items[0] = new StackMapType(input, constant_pool);
+ types_of_stack_items[0] = new StackMapType(input, constantPool);
} else if (frame_type == Const.SAME_LOCALS_1_STACK_ITEM_FRAME_EXTENDED) {
byte_code_offset = input.readShort();
types_of_stack_items = new StackMapType[1];
- types_of_stack_items[0] = new StackMapType(input, constant_pool);
+ types_of_stack_items[0] = new StackMapType(input, constantPool);
} else if (frame_type >= Const.CHOP_FRAME && frame_type <= Const.CHOP_FRAME_MAX) {
byte_code_offset = input.readShort();
} else if (frame_type == Const.SAME_FRAME_EXTENDED) {
@@ -70,19 +70,19 @@ public final class StackMapEntry implements Node, Cloneable
final int number_of_locals = frame_type - 251;
types_of_locals = new StackMapType[number_of_locals];
for (int i = 0; i < number_of_locals; i++) {
- types_of_locals[i] = new StackMapType(input, constant_pool);
+ types_of_locals[i] = new StackMapType(input, constantPool);
}
} else if (frame_type == Const.FULL_FRAME) {
byte_code_offset = input.readShort();
final int number_of_locals = input.readShort();
types_of_locals = new StackMapType[number_of_locals];
for (int i = 0; i < number_of_locals; i++) {
- types_of_locals[i] = new StackMapType(input, constant_pool);
+ types_of_locals[i] = new StackMapType(input, constantPool);
}
final int number_of_stack_items = input.readShort();
types_of_stack_items = new StackMapType[number_of_stack_items];
for (int i = 0; i < number_of_stack_items; i++) {
- types_of_stack_items[i] = new StackMapType(input, constant_pool);
+ types_of_stack_items[i] = new StackMapType(input, constantPool);
}
} else {
/* Can't happen */
@@ -93,42 +93,42 @@ public final class StackMapEntry implements Node, Cloneable
/**
* DO NOT USE
*
* @param byte_code_offset
* @param number_of_locals NOT USED
* @param types_of_locals array of {@link StackMapType}s of locals
* @param number_of_stack_items NOT USED
* @param types_of_stack_items array ot {@link StackMapType}s of stack items
* @param constant_pool the constant pool
* @deprecated Since 6.0, use {@link #StackMapEntry(int, int, StackMapType[], StackMapType[], ConstantPool)}
* instead
*/
@java.lang.Deprecated
- public StackMapEntry(final int byte_code_offset, final int number_of_locals,
- final StackMapType[] types_of_locals, final int number_of_stack_items,
- final StackMapType[] types_of_stack_items, final ConstantPool constant_pool) {
- this.byte_code_offset = byte_code_offset;
- this.types_of_locals = types_of_locals != null ? types_of_locals : new StackMapType[0];
- this.types_of_stack_items = types_of_stack_items != null ? types_of_stack_items : new StackMapType[0];
- this.constant_pool = constant_pool;
+ public StackMapEntry(final int byteCodeOffset, final int numberOfLocals,
+ final StackMapType[] typesOfLocals, final int numberOfStackItems,
+ final StackMapType[] typesOfStackItems, final ConstantPool constantPool) {
+ this.byte_code_offset = byteCodeOffset;
+ this.types_of_locals = typesOfLocals != null ? typesOfLocals : new StackMapType[0];
+ this.types_of_stack_items = typesOfStackItems != null ? typesOfStackItems : new StackMapType[0];
+ this.constant_pool = constantPool;
}
/**
* Create an instance
*
* @param tag the frame_type to use
* @param byte_code_offset
* @param types_of_locals array of {@link StackMapType}s of locals
* @param types_of_stack_items array ot {@link StackMapType}s of stack items
* @param constant_pool the constant pool
*/
- public StackMapEntry(final int tag, final int byte_code_offset,
- final StackMapType[] types_of_locals,
- final StackMapType[] types_of_stack_items, final ConstantPool constant_pool) {
+ public StackMapEntry(final int tag, final int byteCodeOffset,
+ final StackMapType[] typesOfLocals,
+ final StackMapType[] typesOfStackItems, final ConstantPool constantPool) {
this.frame_type = tag;
- this.byte_code_offset = byte_code_offset;
- this.types_of_locals = types_of_locals != null ? types_of_locals : new StackMapType[0];
- this.types_of_stack_items = types_of_stack_items != null ? types_of_stack_items : new StackMapType[0];
- this.constant_pool = constant_pool;
+ this.byte_code_offset = byteCodeOffset;
+ this.types_of_locals = typesOfLocals != null ? typesOfLocals : new StackMapType[0];
+ this.types_of_stack_items = typesOfStackItems != null ? typesOfStackItems : new StackMapType[0];
+ this.constant_pool = constantPool;
}
@@ -93,42 +93,42 @@ public final class StackMapEntry implements Node, Cloneable
* DO NOT USE
*
- * @param byte_code_offset
- * @param number_of_locals NOT USED
- * @param types_of_locals array of {@link StackMapType}s of locals
- * @param number_of_stack_items NOT USED
- * @param types_of_stack_items array ot {@link StackMapType}s of stack items
- * @param constant_pool the constant pool
+ * @param byteCodeOffset
+ * @param numberOfLocals NOT USED
+ * @param typesOfLocals array of {@link StackMapType}s of locals
+ * @param numberOfStackItems NOT USED
+ * @param typesOfStackItems array ot {@link StackMapType}s of stack items
+ * @param constantPool the constant pool
* @deprecated Since 6.0, use {@link #StackMapEntry(int, int, StackMapType[], StackMapType[], ConstantPool)}
* instead
@@ -93,42 +93,42 @@ public final class StackMapEntry implements Node, Cloneable
*
* @param tag the frame_type to use
- * @param byte_code_offset
- * @param types_of_locals array of {@link StackMapType}s of locals
- * @param types_of_stack_items array ot {@link StackMapType}s of stack items
- * @param constant_pool the constant pool
+ * @param byteCodeOffset
+ * @param typesOfLocals array of {@link StackMapType}s of locals
+ * @param typesOfStackItems array ot {@link StackMapType}s of stack items
+ * @param constantPool the constant pool
*/